DataType

Enum DataType 

pub enum DataType {
    StructType {
        name: Option<String>,
        variables: Vec<Variable>,
    },
    EnumType {
        name: Option<String>,
        numeric_type: String,
        elements: AstNode,
    },
    SubRangeType {
        name: Option<String>,
        referenced_type: String,
        referenced_type_location: SourceLocation,
        bounds: Option<AstNode>,
    },
    ArrayType {
        name: Option<String>,
        bounds: AstNode,
        referenced_type: Box<DataTypeDeclaration>,
        is_variable_length: bool,
    },
    PointerType {
        name: Option<String>,
        referenced_type: Box<DataTypeDeclaration>,
        auto_deref: Option<AutoDerefType>,
        type_safe: bool,
        is_function: bool,
    },
    StringType {
        name: Option<String>,
        is_wide: bool,
        size: Option<AstNode>,
    },
    VarArgs {
        referenced_type: Option<Box<DataTypeDeclaration>>,
        sized: bool,
    },
    GenericType {
        name: String,
        generic_symbol: String,
        nature: TypeNature,
    },
}

Variants



StructType

Fields

variables: Vec<Variable>


EnumType

Fields

numeric_type: String
elements: AstNode


SubRangeType

Fields

referenced_type: String
referenced_type_location: SourceLocation

Source location of referenced_type. Used by validation to point at the actual offending token when the referenced type is unknown.

bounds: Option<AstNode>


ArrayType

Fields

bounds: AstNode
referenced_type: Box<DataTypeDeclaration>
is_variable_length: bool


PointerType

Fields

referenced_type: Box<DataTypeDeclaration>
auto_deref: Option<AutoDerefType>
type_safe: bool

Indicates whether to perform type validation. When false, pointer type mismatches are allowed, e.g., foo : POINTER TO DINT := ADR(stringValue). When true, the type of the pointer must match the referenced type exactly.

is_function: bool

Indicates whether the pointer is a function pointer.



StringType

Fields

is_wide: bool


VarArgs

Fields

referenced_type: Option<Box<DataTypeDeclaration>>
sized: bool


GenericType

Fields

name: String
generic_symbol: String
nature: TypeNature

Implementations

Source

impl DataType

pub fn set_name(&mut self, new_name: String)

pub fn get_name(&self) -> Option<&str>

pub fn replace_data_type_with_reference_to( &mut self, type_name: String, location: &SourceLocation, ) -> Option<DataTypeDeclaration>

pub fn is_pointer(&self) -> bool

pub fn is_type_safe_pointer(&self) -> bool

pub fn is_generic(&self) -> bool