pub enum LinkageType {
Internal,
External,
Include,
BuiltIn,
}Variants
Internal
The element is declared in the project currently being complied
External
The element is declared externally and being used by the project
Include
This indicates an element has been included as part of the library. This is equivalant to external in almost all cases. The only difference is when code is in constructor functions where an external function can get a constructor, while an included function will not. See compile flag ´generate-external-constructors´
BuiltIn
This indicates an element that should not have any declarations within the compiled project For example a built in function is implied to exist but not declared
Implementations
Sourceimpl LinkageType
impl LinkageType
pub fn is_external_or_included(&self) -> bool
pub fn is_external(&self) -> bool
pub fn is_included(&self) -> bool
pub fn is_built_in(&self) -> bool