pub struct Assignment {
pub left: Box<AstNode>,
pub right: Box<AstNode>,
}Fields
left: Box<AstNode>right: Box<AstNode>Trait Implementations
Sourceimpl Clone for Assignment
impl Clone for Assignment
Sourcefn clone(&self) -> Assignment
fn clone(&self) -> Assignment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Assignment
impl Debug for Assignment
Sourceimpl<'de> Deserialize<'de> for Assignmentwhere
'de: 'static,
impl<'de> Deserialize<'de> for Assignmentwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Assignment
impl PartialEq for Assignment
Sourcefn eq(&self, other: &Assignment) -> bool
fn eq(&self, other: &Assignment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Assignment
impl Serialize for Assignment
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime Assignment
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime Assignment
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut Assignment
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut Assignment
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for Assignment
impl TryFrom<AstStatement> for Assignment
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for Assignment
impl Walker for Assignment
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for Assignment
impl WalkerMut for Assignment
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for Assignment