pub struct BinaryExpression {
pub operator: Operator,
pub left: Box<AstNode>,
pub right: Box<AstNode>,
}Fields
operator: Operatorleft: Box<AstNode>right: Box<AstNode>Trait Implementations
Sourceimpl Clone for BinaryExpression
impl Clone for BinaryExpression
Sourcefn clone(&self) -> BinaryExpression
fn clone(&self) -> BinaryExpression
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BinaryExpression
impl Debug for BinaryExpression
Sourceimpl<'de> Deserialize<'de> for BinaryExpressionwhere
'de: 'static,
impl<'de> Deserialize<'de> for BinaryExpressionwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BinaryExpression
impl PartialEq for BinaryExpression
Sourcefn eq(&self, other: &BinaryExpression) -> bool
fn eq(&self, other: &BinaryExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BinaryExpression
impl Serialize for BinaryExpression
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime BinaryExpression
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime BinaryExpression
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut BinaryExpression
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut BinaryExpression
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for BinaryExpression
impl TryFrom<AstStatement> for BinaryExpression
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for BinaryExpression
impl Walker for BinaryExpression
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for BinaryExpression
impl WalkerMut for BinaryExpression
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for BinaryExpression