pub struct CallStatement {
pub operator: Box<AstNode>,
pub parameters: Option<Box<AstNode>>,
}Fields
operator: Box<AstNode>parameters: Option<Box<AstNode>>Trait Implementations
Sourceimpl Clone for CallStatement
impl Clone for CallStatement
Sourcefn clone(&self) -> CallStatement
fn clone(&self) -> CallStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CallStatement
impl Debug for CallStatement
Sourceimpl<'de> Deserialize<'de> for CallStatementwhere
'de: 'static,
impl<'de> Deserialize<'de> for CallStatementwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CallStatement
impl PartialEq for CallStatement
Sourcefn eq(&self, other: &CallStatement) -> bool
fn eq(&self, other: &CallStatement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CallStatement
impl Serialize for CallStatement
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime CallStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime CallStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut CallStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut CallStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for CallStatement
impl TryFrom<AstStatement> for CallStatement
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for CallStatement
impl Walker for CallStatement
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for CallStatement
impl WalkerMut for CallStatement
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for CallStatement