pub struct DirectAccess {
pub access: DirectAccessType,
pub index: Box<AstNode>,
}Fields
access: DirectAccessTypeindex: Box<AstNode>Trait Implementations
Sourceimpl Clone for DirectAccess
impl Clone for DirectAccess
Sourcefn clone(&self) -> DirectAccess
fn clone(&self) -> DirectAccess
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DirectAccess
impl Debug for DirectAccess
Sourceimpl<'de> Deserialize<'de> for DirectAccesswhere
'de: 'static,
impl<'de> Deserialize<'de> for DirectAccesswhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DirectAccess
impl PartialEq for DirectAccess
Sourcefn eq(&self, other: &DirectAccess) -> bool
fn eq(&self, other: &DirectAccess) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DirectAccess
impl Serialize for DirectAccess
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime DirectAccess
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime DirectAccess
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut DirectAccess
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut DirectAccess
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for DirectAccess
impl TryFrom<AstStatement> for DirectAccess
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for DirectAccess
impl Walker for DirectAccess
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for DirectAccess
impl WalkerMut for DirectAccess
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for DirectAccess