pub struct EmptyStatement {}Trait Implementations
Sourceimpl Clone for EmptyStatement
impl Clone for EmptyStatement
Sourcefn clone(&self) -> EmptyStatement
fn clone(&self) -> EmptyStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmptyStatement
impl Debug for EmptyStatement
Sourceimpl<'de> Deserialize<'de> for EmptyStatement
impl<'de> Deserialize<'de> for EmptyStatement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EmptyStatement
impl PartialEq for EmptyStatement
Sourcefn eq(&self, other: &EmptyStatement) -> bool
fn eq(&self, other: &EmptyStatement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EmptyStatement
impl Serialize for EmptyStatement
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime EmptyStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime EmptyStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut EmptyStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut EmptyStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for EmptyStatement
impl TryFrom<AstStatement> for EmptyStatement
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
impl StructuralPartialEq for EmptyStatement