pub struct JumpStatement {
pub condition: Box<AstNode>,
pub target: Box<AstNode>,
}Expand description
Represents a conditional jump from current location to a specified label
Fields
condition: Box<AstNode>The condition based on which the current statement will perform a jump
target: Box<AstNode>The target location (Label) the statement will jump to