pub struct LabelStatement {
pub name: String,
}Expand description
Represents a location in code that could be jumbed to
Fields
name: StringTrait Implementations
Sourceimpl Clone for LabelStatement
impl Clone for LabelStatement
Sourcefn clone(&self) -> LabelStatement
fn clone(&self) -> LabelStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LabelStatement
impl Debug for LabelStatement
Sourceimpl<'de> Deserialize<'de> for LabelStatement
impl<'de> Deserialize<'de> for LabelStatement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LabelStatement
impl PartialEq for LabelStatement
Sourcefn eq(&self, other: &LabelStatement) -> bool
fn eq(&self, other: &LabelStatement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LabelStatement
impl Serialize for LabelStatement
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime LabelStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime LabelStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut LabelStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut LabelStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for LabelStatement
impl TryFrom<AstStatement> for LabelStatement
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
impl StructuralPartialEq for LabelStatement