pub struct MultipliedStatement {
pub multiplier: u32,
pub element: Box<AstNode>,
}Fields
multiplier: u32element: Box<AstNode>Trait Implementations
Sourceimpl Clone for MultipliedStatement
impl Clone for MultipliedStatement
Sourcefn clone(&self) -> MultipliedStatement
fn clone(&self) -> MultipliedStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultipliedStatement
impl Debug for MultipliedStatement
Sourceimpl<'de> Deserialize<'de> for MultipliedStatementwhere
'de: 'static,
impl<'de> Deserialize<'de> for MultipliedStatementwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MultipliedStatement
impl PartialEq for MultipliedStatement
Sourcefn eq(&self, other: &MultipliedStatement) -> bool
fn eq(&self, other: &MultipliedStatement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MultipliedStatement
impl Serialize for MultipliedStatement
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime MultipliedStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime MultipliedStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut MultipliedStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut MultipliedStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for MultipliedStatement
impl TryFrom<AstStatement> for MultipliedStatement
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for MultipliedStatement
impl Walker for MultipliedStatement
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for MultipliedStatement
impl WalkerMut for MultipliedStatement
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for MultipliedStatement