pub struct PropertyBlock {
pub ident: Identifier,
pub implementations: Vec<PropertyImplementation>,
}Expand description
The property container as a whole, which contains PropertyImplementations
Fields
ident: Identifierimplementations: Vec<PropertyImplementation>Trait Implementations
Sourceimpl Clone for PropertyBlock
impl Clone for PropertyBlock
Sourcefn clone(&self) -> PropertyBlock
fn clone(&self) -> PropertyBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PropertyBlock
impl Debug for PropertyBlock
Sourceimpl<'de> Deserialize<'de> for PropertyBlockwhere
'de: 'static,
impl<'de> Deserialize<'de> for PropertyBlockwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for PropertyBlock
impl Hash for PropertyBlock
Sourceimpl PartialEq for PropertyBlock
impl PartialEq for PropertyBlock
Sourcefn eq(&self, other: &PropertyBlock) -> bool
fn eq(&self, other: &PropertyBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PropertyBlock
impl Serialize for PropertyBlock
Sourceimpl Walker for PropertyBlock
impl Walker for PropertyBlock
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for PropertyBlock
impl WalkerMut for PropertyBlock
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl Eq for PropertyBlock
impl StructuralPartialEq for PropertyBlock