pub struct RangeStatement {
pub start: Box<AstNode>,
pub end: Box<AstNode>,
}Fields
start: Box<AstNode>end: Box<AstNode>Trait Implementations
Sourceimpl Clone for RangeStatement
impl Clone for RangeStatement
Sourcefn clone(&self) -> RangeStatement
fn clone(&self) -> RangeStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeStatement
impl Debug for RangeStatement
Sourceimpl<'de> Deserialize<'de> for RangeStatementwhere
'de: 'static,
impl<'de> Deserialize<'de> for RangeStatementwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RangeStatement
impl PartialEq for RangeStatement
Sourcefn eq(&self, other: &RangeStatement) -> bool
fn eq(&self, other: &RangeStatement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RangeStatement
impl Serialize for RangeStatement
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime RangeStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime RangeStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut RangeStatement
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut RangeStatement
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for RangeStatement
impl TryFrom<AstStatement> for RangeStatement
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for RangeStatement
impl Walker for RangeStatement
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for RangeStatement
impl WalkerMut for RangeStatement
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for RangeStatement