pub struct UnaryExpression {
pub operator: Operator,
pub value: Box<AstNode>,
}Fields
operator: Operatorvalue: Box<AstNode>Trait Implementations
Sourceimpl Clone for UnaryExpression
impl Clone for UnaryExpression
Sourcefn clone(&self) -> UnaryExpression
fn clone(&self) -> UnaryExpression
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnaryExpression
impl Debug for UnaryExpression
Sourceimpl<'de> Deserialize<'de> for UnaryExpressionwhere
'de: 'static,
impl<'de> Deserialize<'de> for UnaryExpressionwhere
'de: 'static,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UnaryExpression
impl PartialEq for UnaryExpression
Sourcefn eq(&self, other: &UnaryExpression) -> bool
fn eq(&self, other: &UnaryExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnaryExpression
impl Serialize for UnaryExpression
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime UnaryExpression
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime AstStatement> for &'__deriveMoreLifetime UnaryExpression
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime AstStatement>
The type returned in the event of a conversion error.
Sourceimpl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut UnaryExpression
impl<'__deriveMoreLifetime> TryFrom<&'__deriveMoreLifetime mut AstStatement> for &'__deriveMoreLifetime mut UnaryExpression
Sourcetype Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
type Error = TryIntoError<&'__deriveMoreLifetime mut AstStatement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<AstStatement> for UnaryExpression
impl TryFrom<AstStatement> for UnaryExpression
Sourcetype Error = TryIntoError<AstStatement>
type Error = TryIntoError<AstStatement>
The type returned in the event of a conversion error.
Sourceimpl Walker for UnaryExpression
impl Walker for UnaryExpression
fn walk<V>(&self, visitor: &mut V)where
V: AstVisitor,
Sourceimpl WalkerMut for UnaryExpression
impl WalkerMut for UnaryExpression
fn walk<V>(&mut self, visitor: &mut V)where
V: AstVisitorMut,
impl StructuralPartialEq for UnaryExpression