ReturnStatement

Struct ReturnStatement 

pub struct ReturnStatement {
    pub condition: Option<Box<AstNode>>,
}

Fields

condition: Option<Box<AstNode>>

Indicates that the given condition must evaluate to true in order for the return to take place. Only used in CFC where the condition may be Some and None otherwise.