pub enum AstLiteral {
Null,
Integer(i128),
Date(Date),
DateAndTime(DateAndTime),
TimeOfDay(TimeOfDay),
Time(Time),
Real(String),
Bool(bool),
String(StringValue),
Array(Array),
}Variants
Null
a null literal used to initialize pointers
Integer(i128)
a literal that represents a whole number (e.g. 7)
Date(Date)
a literal that represents a date
DateAndTime(DateAndTime)
a literal that represents a date and time
TimeOfDay(TimeOfDay)
a literal that represents the time of day
Time(Time)
a literal that represents a time period
Real(String)
a literal that represents a real number (e.g. 7.0)
Bool(bool)
a literal that represents a boolean value (true, false)
String(StringValue)
a literal that represents a string
Array(Array)
a literal that represents an array
Implementations
Sourceimpl AstLiteral
impl AstLiteral
Sourcepub fn new_integer(value: i128) -> Self
pub fn new_integer(value: i128) -> Self
Creates a new literal integer
Sourcepub fn new_string(value: String, is_wide: bool) -> Self
pub fn new_string(value: String, is_wide: bool) -> Self
Creates a new literal string
Sourcepub fn new_date_with_long_flag(
year: i32,
month: u32,
day: u32,
is_long: bool,
) -> Self
pub fn new_date_with_long_flag( year: i32, month: u32, day: u32, is_long: bool, ) -> Self
Creates a new literal date with explicit width flavor
Sourcepub fn new_date_and_time(
year: i32,
month: u32,
day: u32,
hour: u32,
min: u32,
sec: u32,
nano: u32,
) -> Self
pub fn new_date_and_time( year: i32, month: u32, day: u32, hour: u32, min: u32, sec: u32, nano: u32, ) -> Self
Creates a new literal date and time
Sourcepub fn new_long_date_and_time(
year: i32,
month: u32,
day: u32,
hour: u32,
min: u32,
sec: u32,
nano: u32,
) -> Self
pub fn new_long_date_and_time( year: i32, month: u32, day: u32, hour: u32, min: u32, sec: u32, nano: u32, ) -> Self
Creates a new long literal date and time
Sourcepub fn new_time_of_day(hour: u32, min: u32, sec: u32, nano: u32) -> Self
pub fn new_time_of_day(hour: u32, min: u32, sec: u32, nano: u32) -> Self
Creates a new literal time of day
Sourcepub fn new_time_of_day_with_long_flag(
hour: u32,
min: u32,
sec: u32,
nano: u32,
is_long: bool,
) -> Self
pub fn new_time_of_day_with_long_flag( hour: u32, min: u32, sec: u32, nano: u32, is_long: bool, ) -> Self
Creates a new literal time of day with explicit width flavor
pub fn get_literal_value(&self) -> String
pub fn is_cast_prefix_eligible(&self) -> bool
pub fn is_numerical(&self) -> bool
pub fn is_zero(&self) -> bool
pub fn get_literal_integer_value(&self) -> Option<i128>